<?php
/**
 * Solar Services functions and definitions
 *
 * @package Solar Services
 */

/**
 * Set the content width based on the theme's design and stylesheet.
 */

if ( ! function_exists( 'solar_services_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which runs
 * before the init hook. The init hook is too late for some features, such as indicating
 * support post thumbnails.
 */
function solar_services_setup() {
	global $content_width;
	if ( ! isset( $content_width ) )
		$content_width = 680;

	add_theme_support( 'automatic-feed-links' );
	add_theme_support( "responsive-embeds" );
	add_theme_support( 'align-wide' );
	add_theme_support( 'woocommerce' );
	add_theme_support( 'post-thumbnails' );
	add_theme_support( 'title-tag' );
	add_theme_support( 'wp-block-styles');
	add_theme_support( 'custom-header', array(
		'default-text-color' => false,
		'header-text' => false,
	) );
	add_theme_support( 'custom-logo', array(
		'height'      => 100,
		'width'       => 100,
		'flex-height' => true,
	) );
	register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'solar-services' ),
	) );
	add_theme_support( 'custom-background', array(
		'default-color' => 'ffffff'
	) );
	add_theme_support( 'html5', array(
		'search-form',
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );
	add_editor_style( 'editor-style.css' );
}
endif; // solar_services_setup
add_action( 'after_setup_theme', 'solar_services_setup' );

function solar_services_the_breadcrumb() {
	if (!is_home()) {
		echo '<a class="home-main" href="';
		echo esc_url( home_url() );
		echo '">';
		bloginfo('name');
		echo "</a> <span style='margin: 0 10px;'>|</span> ";
		if (is_category() || is_single()) {
			the_category(' , ');
			if (is_single()) {
				echo " >> ";
				'<span>'.esc_html(the_title()).'</span>';
			}
		} elseif (is_page()) {
			echo '<span>'.esc_html(the_title()).'</span>';
		}
	}
}

function solar_services_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Blog Sidebar', 'solar-services' ),
		'description'   => __( 'Appears on blog page sidebar', 'solar-services' ),
		'id'            => 'sidebar-1',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
	register_sidebar( array(
		'name'          => __( 'Footer', 'solar-services' ),
		'description'   => __( 'Appears on footer', 'solar-services' ),
		'id'            => 'footer-nav',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
}
add_action( 'widgets_init', 'solar_services_widgets_init' );

function solar_services_scripts() {
	wp_enqueue_style( 'bootstrap-css', get_template_directory_uri()."/css/bootstrap.css" );
	wp_enqueue_style( 'owl.carousel-css', get_template_directory_uri()."/css/owl.carousel.css" );
	wp_enqueue_style( 'solar-services-basic-style', get_stylesheet_uri() );
	wp_enqueue_style( 'solar-services-default',get_template_directory_uri()."/css/default.css" );
	wp_enqueue_script( 'owl.carousel-js', get_template_directory_uri(). '/js/owl.carousel.js', array('jquery') );
	wp_enqueue_script( 'bootstrap-js', get_template_directory_uri(). '/js/bootstrap.js', array('jquery') );
	wp_enqueue_script( 'solar-services-theme',get_template_directory_uri() . '/js/theme.js' );
	
	wp_enqueue_script( 'jquery.superfish', get_template_directory_uri() . '/js/jquery.superfish.js' );
	
	wp_enqueue_style( 'font-awesome-css', get_template_directory_uri()."/css/fontawesome-all.css" );

	wp_enqueue_style( 'solar-services-block-style',get_template_directory_uri().'/css/blocks.css' );
	wp_enqueue_style('solar-services-style', get_stylesheet_uri(), array() );
		wp_style_add_data('solar-services-style', 'rtl', 'replace');
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
	wp_enqueue_style( 'solar-services-Knewave', 'https://fonts.googleapis.com/css2?family=Knewave&display=swap');

	wp_enqueue_style( 'solar-services-Roboto', 'https://fonts.googleapis.com/css2?family=Roboto:ital,wght@0,100;0,300;0,400;0,500;0,700;0,900;1,100;1,300;1,400;1,500;1,700;1,900&display=swap');
}
add_action( 'wp_enqueue_scripts', 'solar_services_scripts' );

// Footer Link
define('SOLAR_SERVICES_FOOTER_LINK',__('https://www.theclassictemplates.com/themes/free-solar-energy-woocommerce-themes/','solar-services'));

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Sanitization Callbacks.
 */
require get_template_directory() . '/inc/sanitization-callbacks.php';


/**
 * PRO Button Link
 */
load_template( trailingslashit( get_template_directory() ) . 'inc/button-link/class-button-link.php' );

if ( ! function_exists( 'solar_services_the_custom_logo' ) ) :
/**
 * Displays the optional custom logo.
 *
 * Does nothing if the custom logo is not available.
 *
 */
function solar_services_the_custom_logo() {
	if ( function_exists( 'the_custom_logo' ) ) {
		the_custom_logo();
	}
}
endif;

//sanitize number field
function solar_services_sanitize_number_absint( $number, $setting ) {
  // Ensure $number is an absolute integer (whole number, zero or greater).
  $number = absint( $number );

  // If the input is an absolute integer, return it; otherwise, return the default
  return ( $number ? $number : $setting->default );
}
